@@ -28,7 +28,7 @@ calcular.indicadores <- function(i.current,
   if (i.equal) umbral.pos <- i.umbral.pre else umbral.pos <- i.umbral.pos
   if (is.na(umbral.pos)) umbral.pos <- i.umbral.pre
   duracion.media <- i.duracion.intensidad
-  punto.maximo <- max.fix.na(i.current)
+  punto.maximo <- maxFixNA(i.current)
   semana.punto.maximo <- min(numero.semana[i.current == punto.maximo], na.rm = T)
   semanas.encima <- i.current[, 1] > umbral.pre
   suma.semanas.encima <- c(rep(NA, i.semanas.por.encima - 1), roll_sum(semanas.encima, i.semanas.por.encima))
@@ -228,7 +228,7 @@ calcular.indicadores <- function(i.current,
 
     # calculo el rango y para que tenga 10 marcas o este cerca
 
-    maximo.y <- max.fix.na(dgraf)
+    maximo.y <- maxFixNA(dgraf)
     posicion.ticks <- optimal.tickmarks(0, maximo.y, 10)$by
     range.y <- c(-1.5 * posicion.ticks, ceiling(maximo.y / posicion.ticks) * posicion.ticks)
     range.y.seq <- seq(0, ceiling(maximo.y / posicion.ticks) * posicion.ticks, posicion.ticks)
