@@ -11,8 +11,8 @@ calcular.map <- function(i.datos) {
       sumasemanas <- c(sumasemanas, sum(datos[i:(i + s - 1)], na.rm = TRUE))
     }
     maxsumasemanas[s, 1] <- s
-    maxsumasemanas[s, 3] <- max.fix.na(sumasemanas)
-    maxsumasemanas[s, 4] <- min((1:(semanas + 1 - s))[max.fix.na(sumasemanas) == sumasemanas])
+    maxsumasemanas[s, 3] <- maxFixNA(sumasemanas)
+    maxsumasemanas[s, 4] <- min((1:(semanas + 1 - s))[maxFixNA(sumasemanas) == sumasemanas])
     maxsumasemanas[s, 5] <- maxsumasemanas[s, 4] + s - 1
   }
   sumaanual <- sum(datos, na.rm = TRUE)
