@@ -2,8 +2,8 @@
 #'
 #' @keywords internal
 normalizar <- function(normalizar.i.datos) {
-  maximo <- max.fix.na(normalizar.i.datos)
-  minimo <- min.fix.na(normalizar.i.datos)
+  maximo <- maxFixNA(normalizar.i.datos)
+  minimo <- minFixNA(normalizar.i.datos)
   resultado <- (normalizar.i.datos - minimo) / (maximo - minimo)
   return(resultado)
 }
